@@ -268,27 +268,47 @@ Stopover EfaXmlParser::parsePartialTripIntermediateStop(ScopedXmlStreamReader &&
     stop.setScheduledPlatform(reader.attributes().value(QLatin1String("platform")).toString());
 
     bool result = false;
-    auto depDelay = reader.attributes().value(QLatin1String("depDelay")).toInt(&result);
-    if (!result) {
-        depDelay = -1;
+    std::optional<int64_t> arrDelay, depDelay;
+    if (reader.attributes().value("depValid") == "1"_L1) {
+        depDelay = reader.attributes().value("depDelay"_L1).toInt(&result);
+        if (!result) {
+            depDelay = {};
+        }
+    }
+    if (reader.attributes().value("arrValid") == "1"_L1) {
+        arrDelay = reader.attributes().value("depDelay"_L1).toInt(&result);
+        if (!result) {
+            arrDelay = {};
+        }
     }
-    // TODO there is also arrDelay - but what's the corresponding date/time for that?
 
+    bool seenItdDateTime = false;
     while (reader.readNextSibling()) {
-        if (reader.name() == QLatin1String("itdDateTime")) {
-            // TODO sometimes there are two itdDateTime elements here?
-            // TODO sometimes there are invalid itdDateTime elements here?
+        if (reader.name() == "itdDateTime"_L1) {
             const auto dt = parseDateTime(reader.subReader());
             if (dt.isValid()) {
-                stop.setScheduledDepartureTime(dt);
-
-                if (depDelay >= 0) {
-                    stop.setExpectedDepartureTime(dt.addSecs(60 * depDelay));
+                if (!seenItdDateTime) {
+                    stop.setScheduledArrivalTime(dt);
+                    if (arrDelay) {
+                        stop.setExpectedArrivalTime(dt.addSecs(60 * (*arrDelay)));
+                    }
+                } else {
+                    stop.setScheduledDepartureTime(dt);
+                    if (depDelay) {
+                        stop.setExpectedArrivalTime(dt.addSecs(60 * (*depDelay)));
+                    }
                 }
             }
+            seenItdDateTime = true;
         }
     }
 
+    // sometimes we only get invalid itdDateTime elements, e.g. in the UK. Semantics of that
+    // is unclear, their own website doesn't show those stops at all
+    if (!stop.scheduledArrivalTime().isValid() && !stop.scheduledDepartureTime().isValid()) {
+        stop.setDisruptionEffect(Disruption::NoService);
+    }
+
     return stop;
 }
 
